@@ -17,13 +17,13 @@ class StateMachine(core.Construct):
     _sm: aws_stepfunctions.IStateMachine = None
     _smprops: dict = {}
     lambdas: dict = {}
-    lambdas_assets: aws_lambda.Code
+    lambdas_assets: aws_lambda.AssetCode
     lambdas_runtime: aws_lambda.Runtime
 
     def __init__(self, scope: core.Construct, id: str, *, lambdas_path=LAMBDAS_PATH, lambdas_runtime=LAMBDAS_RUNTIME, **attr) -> None:
         super().__init__(scope, id, **attr)
         self.lambdas_runtime = lambdas_runtime
-        self.lambdas_assets = aws_lambda.Code.asset(lambdas_path)
+        self.lambdas_assets = aws_lambda.AssetCode.from_asset(lambdas_path)
 
     @property
     def sm(self) -> aws_stepfunctions.StateMachine:
